# This file auto-generated by `generate_schema_interface.py`.
# Do not modify this file directly.

"""
Test that all auto-generated schema objects can be instatiated.
"""

from .. import *


def test_instantiate_AggregateOp():
    obj = AggregateOp()


def test_instantiate_Axis():
    obj = Axis()


def test_instantiate_AxisConfig():
    obj = AxisConfig()


def test_instantiate_AxisOrient():
    obj = AxisOrient()


def test_instantiate_Bin():
    obj = Bin()


def test_instantiate_CellConfig():
    obj = CellConfig()


def test_instantiate_ChannelDefWithLegend():
    obj = ChannelDefWithLegend()


def test_instantiate_Config():
    obj = Config()


def test_instantiate_Data():
    obj = Data()


def test_instantiate_DataFormat():
    obj = DataFormat()


def test_instantiate_Encoding():
    obj = Encoding()


def test_instantiate_ExtendedUnitSpec():
    obj = ExtendedUnitSpec()


def test_instantiate_Facet():
    obj = Facet()


def test_instantiate_FacetConfig():
    obj = FacetConfig()


def test_instantiate_FacetGridConfig():
    obj = FacetGridConfig()


def test_instantiate_FacetScaleConfig():
    obj = FacetScaleConfig()


def test_instantiate_FacetSpec():
    obj = FacetSpec()


def test_instantiate_FieldDef():
    obj = FieldDef()


def test_instantiate_FontStyle():
    obj = FontStyle()


def test_instantiate_FontWeight():
    obj = FontWeight()


def test_instantiate_Formula():
    obj = Formula()


def test_instantiate_HorizontalAlign():
    obj = HorizontalAlign()


def test_instantiate_Interpolate():
    obj = Interpolate()


def test_instantiate_LayerSpec():
    obj = LayerSpec()


def test_instantiate_Legend():
    obj = Legend()


def test_instantiate_LegendConfig():
    obj = LegendConfig()


def test_instantiate_Mark():
    obj = Mark()


def test_instantiate_MarkConfig():
    obj = MarkConfig()


def test_instantiate_NiceTime():
    obj = NiceTime()


def test_instantiate_OrderChannelDef():
    obj = OrderChannelDef()


def test_instantiate_PositionChannelDef():
    obj = PositionChannelDef()


def test_instantiate_Scale():
    obj = Scale()


def test_instantiate_ScaleConfig():
    obj = ScaleConfig()


def test_instantiate_ScaleType():
    obj = ScaleType()


def test_instantiate_Shape():
    obj = Shape()


def test_instantiate_SortField():
    obj = SortField()


def test_instantiate_SortOrder():
    obj = SortOrder()


def test_instantiate_StackOffset():
    obj = StackOffset()


def test_instantiate_TimeUnit():
    obj = TimeUnit()


def test_instantiate_Transform():
    obj = Transform()


def test_instantiate_Type():
    obj = Type()


def test_instantiate_UnitEncoding():
    obj = UnitEncoding()


def test_instantiate_UnitSpec():
    obj = UnitSpec()


def test_instantiate_VerticalAlign():
    obj = VerticalAlign()

