# This file auto-generated by `generate_schema_interface.py`.
# Do not modify this file directly.

from .channel_wrappers import ChannelWithLegend, Field, OrderChannel, PositionChannel


class Color(ChannelWithLegend):
    pass


class Column(PositionChannel):
    pass


class Detail(Field):
    pass


class Label(Field):
    pass


class Opacity(ChannelWithLegend):
    pass


class Order(OrderChannel):
    pass


class Path(OrderChannel):
    pass


class Row(PositionChannel):
    pass


class Shape(ChannelWithLegend):
    pass


class Size(ChannelWithLegend):
    pass


class Text(Field):
    pass


class X(PositionChannel):
    pass


class Y(PositionChannel):
    pass


