# This file auto-generated by `generate_schema_interface.py`.
# Do not modify this file directly.

import traitlets as T
from ..baseobject import BaseObject
from .positionchanneldef import PositionChannelDef


class Facet(BaseObject):
    """Wrapper for Vega-Lite Facet definition.
    
    Attributes
    ----------
    column: PositionChannelDef
        
    row: PositionChannelDef
        
    """
    column = T.Instance(PositionChannelDef, allow_none=True, default_value=None)
    row = T.Instance(PositionChannelDef, allow_none=True, default_value=None)
    
    def __init__(self, column=None, row=None, **kwargs):
        kwds = dict(column=column, row=row)
        kwargs.update({k:v for k, v in kwds.items() if v is not None})
        super(Facet, self).__init__(**kwargs)