# This file auto-generated by `generate_schema_interface.py`.
# Do not modify this file directly.

import traitlets as T
from ..baseobject import BaseObject


class FacetScaleConfig(BaseObject):
    """Wrapper for Vega-Lite FacetScaleConfig definition.
    
    Attributes
    ----------
    padding: CFloat
        
    round: Bool
        
    """
    padding = T.CFloat(allow_none=True, default_value=None)
    round = T.Bool(allow_none=True, default_value=None)
    
    def __init__(self, padding=None, round=None, **kwargs):
        kwds = dict(padding=padding, round=round)
        kwargs.update({k:v for k, v in kwds.items() if v is not None})
        super(FacetScaleConfig, self).__init__(**kwargs)