# This file auto-generated by `generate_schema_interface.py`.
# Do not modify this file directly.

import traitlets as T


class ScaleType(T.Enum):
    """One of ['linear', 'log', 'pow', 'sqrt', 'quantile', 'quantize', 'ordinal', 'time', 'utc']"""
    def __init__(self, default_value=T.Undefined, **metadata):
        super(ScaleType, self).__init__(['linear', 'log', 'pow', 'sqrt', 'quantile', 'quantize', 'ordinal', 'time', 'utc'],
                                    default_value=default_value,
                                    **metadata)